# start-url

![Github CI](https://github.com/justmars/start-url/actions/workflows/main.yml/badge.svg)

## Development

See [documentation](https://justmars.github.io/start-url).

1. Run `poetry install`
2. Run `poetry shell`
3. Run `pytest`
